@@ -8,21 +8,23 @@ sub has_many {
     
   eval "require $f_class";
 
-  if (!ref $cond) {
-    my $f_key;
-    if (defined $cond && length $cond) {
-      $f_key = $cond;
-      $class->throw( "No such column ${f_key} on foreign class ${f_class}" )
-        unless ($@ || $f_class->_columns->{$f_key});
-    } else {
-      $class =~ /([^\:]+)$/;
-      $f_key = lc $1 if $f_class->_columns->{lc $1};
-      $class->throw( "Unable to resolve foreign key for has_many from ${class} to ${f_class}" )
-        unless $f_key;
-    }
+  unless (ref $cond) {
     my ($pri, $too_many) = keys %{ $class->_primaries };
     $class->throw( "has_many can only infer join for a single primary key; ${class} has more" )
       if $too_many;
+    my $f_key;
+    my $f_class_loaded = eval { $f_class->_columns };
+    my $guess;
+    if (defined $cond && length $cond) {
+      $f_key = $cond;
+      $guess = "caller specified foreign key '$f_key'";
+    } else {
+      $class =~ /([^\:]+)$/;
+      $f_key = lc $1; # go ahead and guess; best we can do
+      $guess = "using our class name '$class' as foreign key";
+    }
+    $class->throw("No such column ${f_key} on foreign class ${f_class} ($guess)")
+      if $f_class_loaded && !exists $f_class->_columns->{$f_key}; 
     $cond = { "foreign.${f_key}" => "self.${pri}" },
   }
 
